@@ -15,7 +15,7 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-__version_info__ = (3, 83, 0)
-__version__ = '.'.join(map(str, __version_info__))
+__version_info__ = (3, 83, 2)
+__version__ = ".".join(map(str, __version_info__))
